@@ -1,9 +1,16 @@
 import os
-
+import ipynbname
 from ml_sdk.ml.model.notebook import WatchmenNotebook
 from ml_sdk.ml.sdk.watchmen.sdk import load_dataset_by_name
 
 
+def get_notebook():
+    note_name = ipynbname.name()
+    path = ipynbname.path()
+    notebook = WatchmenNotebook(name=note_name,storageLocation= path)
+    return notebook
+
+
 class WatchmenClient(object):
     def __init__(self,token):
         if token:
@@ -15,9 +22,10 @@ class WatchmenClient(object):
         return load_dataset_by_name(self.token,name)
 
 
-    def register_notebook(self,notebook:WatchmenNotebook):
-        print(notebook)
-        pass
+    def register_notebook(self):
+        notebook = get_notebook()
+        return notebook
+
 
     def save_topic_dataset(self,topic_name:str, dataset):
         pass
